Installation — mpes 0.9.8 documentation

# Installation

The `mpes` package and its main dependencies can be installed in the following ways:

Install from git repository

    pip install git+https://github.com/RealPolitiX/mpes.git

Install and upgrade to the latest version

    pip install --upgrade git+https://github.com/mpes-kit/mpes.git

The following are the main dependencies

    numpy = 0.13.0 +
    scipy = 0.19.0 +
    scikit-image = 0.13.0 +
    pandas = 0.19.2 +
    dask >= 0.18.0
    xarray
    opencv

Other dependencies essential for loading the submodules are described in the requirements file. There are situations where additional dependencies are needed to execute certain functionalities that are not essential for general use. The users need to install the dependencies separately should they wish to use them, otherwise a warning would be thrown to remind the user. This construct reduces the potential conflicts between dependencies and permits the main functionalities of the package to be run without being affected by minor dependencies.